@@ -38,6 +38,13 @@ nblag <- function(neighbours, maxlag)
 		class(lags[[i]]) <- "nb"
 		attr(lags[[i]], "region.id") <- attr(neighbours, "region.id")
 		lags[[i]] <- sym.attr.nb(lags[[i]])
+                NE <- length(lags[[i]]) + sum(card(lags[[i]]))
+                if (get.SubgraphOption() && get.SubgraphCeiling() > NE) {
+                    ncomp <- n.comp.nb(lags[[i]])
+                    attr(lags[[i]], "ncomp") <- ncomp
+                    if (ncomp$nc > 1) warning("lag ", i,
+                        " neighbour object has ", ncomp$nc, " sub-graphs")
+                }
 	}
 	attr(lags, "call") <- match.call()
 	lags
@@ -67,5 +74,9 @@ nblag_cumul <- function (nblags) {
     attr(lags, "region.id") <- attr(nblags[[1]], "region.id")
     attr(lags, "call") <- match.call()
     class(lags) <- "nb"
+    if (get.SubgraphOption()) {
+        nsg <- n.comp.nb(lags)$nc
+        if (nsg > 1) warning("neighbour object has ", nsg, " sub-graphs")
+    }
     lags
 }
