@@ -1,11 +1,18 @@
 ## ---------------------------------------------------------------------------------------
 library(spdep)
-NY8 <- as(sf::st_read(system.file("shapes/NY8_utm18.shp", package="spData")), "Spatial")
+if (packageVersion("spData") >= "2.3.2") {
+    NY8a <- sf::st_read(system.file("shapes/NY8_utm18.gpkg", package="spData"))
+} else {
+    NY8a <- sf::st_read(system.file("shapes/NY8_bna_utm18.gpkg", package="spData"))
+    sf::st_crs(NY8a) <- "EPSG:32618"
+    NY8a$Cases <- NY8a$TRACTCAS
+}
+NY8 <- as(NY8a, "Spatial")
 NY_nb <- read.gal(system.file("weights/NY_nb.gal", package="spData"), region.id=as.character(as.integer(row.names(NY8))-1L))
 
 ## ---------------------------------------------------------------------------------------
-Syracuse <- NY8[NY8$AREANAME == "Syracuse city",]
-Sy0_nb <- subset(NY_nb, NY8$AREANAME == "Syracuse city")
+Syracuse <- NY8[!is.na(NY8$AREANAME) & NY8$AREANAME == "Syracuse city",]
+Sy0_nb <- subset(NY_nb, !is.na(NY8$AREANAME) & NY8$AREANAME == "Syracuse city")
 summary(Sy0_nb)
 
 ## ---------------------------------------------------------------------------------------
@@ -20,24 +27,28 @@ isTRUE(all.equal(Sy0_nb, Sy2_nb, check.attributes=FALSE))
 ## ----echo=FALSE,eval=TRUE---------------------------------------------------------------
 run <- require("sp", quiet=TRUE)
 
-## ----echo=run---------------------------------------------------------------------------
-oopar <- par(mfrow=c(1,2), mar=c(3,3,1,1)+0.1)
-plot(Syracuse, border="grey60")
-plot(Sy0_nb, coordinates(Syracuse), add=TRUE, pch=19, cex=0.6)
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
-plot(Syracuse, border="grey60")
-plot(Sy0_nb, coordinates(Syracuse), add=TRUE, pch=19, cex=0.6)
-plot(diffnb(Sy0_nb, Sy2_nb, verbose=FALSE), coordinates(Syracuse),
-  add=TRUE, pch=".", cex=0.6, lwd=2)
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
-par(oopar)
+## ----echo=TRUE,eval=FALSE---------------------------------------------------------------
+#  oopar <- par(mfrow=c(1,2), mar=c(3,3,1,1)+0.1)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy0_nb, coordinates(Syracuse), add=TRUE, pch=19, cex=0.6)
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy0_nb, coordinates(Syracuse), add=TRUE, pch=19, cex=0.6)
+#  plot(diffnb(Sy0_nb, Sy2_nb, verbose=FALSE), coordinates(Syracuse),
+#    add=TRUE, pch=".", cex=0.6, lwd=2, col="orange")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
+#  par(oopar)
 
 ## ----eval=FALSE-------------------------------------------------------------------------
-#  library(spgrass6)
-#  writeVECT6(Syracuse, "SY0")
+#  library(rgrass)
+#  v <- terra::vect(sf::st_as_sf(Syracuse))
+#  SG <- terra::rast(terra::ext(v), crs=terra::crs(v))
+#  pr <- initGRASS("/home/rsb/topics/grass/g840/grass84", tempdir(), SG=SG, override=TRUE)
+#  write_VECT(v, "SY0", flags=c("o", "overwrite"))
 #  contig <- vect2neigh("SY0")
-#  Sy3_nb <- sn2listw(contig)$neighbours
+#  Sy3_nb <- sn2listw(contig, style="B")$neighbours
 #  isTRUE(all.equal(Sy3_nb, Sy2_nb, check.attributes=FALSE))
+#  ## [1] TRUE
 
 ## ----echo=run---------------------------------------------------------------------------
 coords <- coordinates(Syracuse)
@@ -50,23 +61,23 @@ if (require(dbscan, quietly=TRUE)) {
 Sy6_nb <- graph2nb(gabrielneigh(coords), row.names=IDs)
 Sy7_nb <- graph2nb(relativeneigh(coords), row.names=IDs)
 
-## ----echo=run---------------------------------------------------------------------------
-oopar <- par(mfrow=c(2,2), mar=c(1,1,1,1)+0.1)
-plot(Syracuse, border="grey60")
-plot(Sy4_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
-plot(Syracuse, border="grey60")
-if (!is.null(Sy5_nb)) {
-  plot(Sy5_nb, coords, add=TRUE, pch=".")
-  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
-}
-plot(Syracuse, border="grey60")
-plot(Sy6_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="c)", cex=0.8)
-plot(Syracuse, border="grey60")
-plot(Sy7_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="d)", cex=0.8)
-par(oopar)
+## ----echo=run,eval=FALSE----------------------------------------------------------------
+#  oopar <- par(mfrow=c(2,2), mar=c(1,1,1,1)+0.1)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy4_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
+#  plot(Syracuse, border="grey60")
+#  if (!is.null(Sy5_nb)) {
+#    plot(Sy5_nb, coords, add=TRUE, pch=".")
+#    text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
+#  }
+#  plot(Syracuse, border="grey60")
+#  plot(Sy6_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="c)", cex=0.8)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy7_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="d)", cex=0.8)
+#  par(oopar)
 
 ## ----echo=run---------------------------------------------------------------------------
 nb_l <- list(Triangulation=Sy4_nb, Gabriel=Sy6_nb,
@@ -83,18 +94,18 @@ nb_l <- list(k1=Sy8_nb, k2=Sy9_nb, k4=Sy10_nb)
 sapply(nb_l, function(x) is.symmetric.nb(x, verbose=FALSE, force=TRUE))
 sapply(nb_l, function(x) n.comp.nb(x)$nc)
 
-## ----echo=run---------------------------------------------------------------------------
-oopar <- par(mfrow=c(1,3), mar=c(1,1,1,1)+0.1)
-plot(Syracuse, border="grey60")
-plot(Sy8_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
-plot(Syracuse, border="grey60")
-plot(Sy9_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
-plot(Syracuse, border="grey60")
-plot(Sy10_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="c)", cex=0.8)
-par(oopar)
+## ----echo=run,eval=FALSE----------------------------------------------------------------
+#  oopar <- par(mfrow=c(1,3), mar=c(1,1,1,1)+0.1)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy8_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy9_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy10_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="c)", cex=0.8)
+#  par(oopar)
 
 ## ----echo=run---------------------------------------------------------------------------
 dsts <- unlist(nbdists(Sy8_nb, coords))
@@ -108,18 +119,18 @@ nb_l <- list(d1=Sy11_nb, d2=Sy12_nb, d3=Sy13_nb)
 sapply(nb_l, function(x) is.symmetric.nb(x, verbose=FALSE, force=TRUE))
 sapply(nb_l, function(x) n.comp.nb(x)$nc)
 
-## ----echo=run---------------------------------------------------------------------------
-oopar <- par(mfrow=c(1,3), mar=c(1,1,1,1)+0.1)
-plot(Syracuse, border="grey60")
-plot(Sy11_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
-plot(Syracuse, border="grey60")
-plot(Sy12_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
-plot(Syracuse, border="grey60")
-plot(Sy13_nb, coords, add=TRUE, pch=".")
-text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="c)", cex=0.8)
-par(oopar)
+## ----echo=run,eval=FALSE----------------------------------------------------------------
+#  oopar <- par(mfrow=c(1,3), mar=c(1,1,1,1)+0.1)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy11_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="a)", cex=0.8)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy12_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="b)", cex=0.8)
+#  plot(Syracuse, border="grey60")
+#  plot(Sy13_nb, coords, add=TRUE, pch=".")
+#  text(bbox(Syracuse)[1,1], bbox(Syracuse)[2,2], labels="c)", cex=0.8)
+#  par(oopar)
 
 ## ----echo=run---------------------------------------------------------------------------
 dS <- c(0.75, 1, 1.5)*max_1nn
