@@ -1,9 +1,6 @@
 /* Copyright 2002 by Roger S. Bivand. */
 
-#include <R.h>
-#include <Rdefines.h>
-#include <R_ext/Applic.h>
-#define ROFFSET 1
+#include "spdep.h"
 
 SEXP gearyw(SEXP nb, SEXP weights, SEXP x, SEXP card, SEXP zeropolicy,
 	SEXP ftype) {
@@ -13,6 +10,7 @@ SEXP gearyw(SEXP nb, SEXP weights, SEXP x, SEXP card, SEXP zeropolicy,
 	PROTECT(ans = NEW_NUMERIC(n)); pc++;
 
 	for (i=0; i < n; i++) {
+            R_CheckUserInterrupt();
 	    if (INTEGER_POINTER(card)[i] == 0) {
 		if (LOGICAL_POINTER(zeropolicy)[0] == TRUE)
 		    NUMERIC_POINTER(ans)[i] = 0;
